pub struct FeerateEstimations {
pub priority_bucket: FeerateBucket,
pub normal_buckets: Vec<FeerateBucket>,
pub low_buckets: Vec<FeerateBucket>,
}Fields
priority_bucket: FeerateBucketTop-priority feerate bucket. Provides an estimation of the feerate required for sub-second DAG inclusion.
Note: for all buckets, feerate values represent fee/mass of a transaction in sompi/gram units.
Given a feerate value recommendation, calculate the required fee by
taking the transaction mass and multiplying it by feerate: fee = feerate * mass(tx)
normal_buckets: Vec<FeerateBucket>A vector of normal priority feerate values. The first value of this vector is guaranteed to exist and
provide an estimation for sub-minute DAG inclusion. All other values will have shorter estimation
times than all low_bucket values. Therefor by chaining [priority] | normal | low and interpolating
between them, one can compose a complete feerate function on the client side. The API makes an effort
to sample enough “interesting” points on the feerate-to-time curve, so that the interpolation is meaningful.
low_buckets: Vec<FeerateBucket>A vector of low priority feerate values. The first value of this vector is guaranteed to exist and provide an estimation for sub-hour DAG inclusion.
Implementations
Sourceimpl FeerateEstimations
impl FeerateEstimations
pub fn ordered_buckets(&self) -> Vec<FeerateBucket>