Feerate

Type Alias Feerate 

pub type Feerate = f64;
A type representing fee/mass of a transaction in sompi/gram units. Given a feerate value recommendation, calculate the required fee by taking the transaction mass and multiplying it by feerate: fee = feerate * mass(tx)