RbfPolicy

Enum RbfPolicy 

pub enum RbfPolicy {
    Forbidden,
    Allowed,
    Mandatory,
}
Replace by Fee (RBF) policy

Variants



Forbidden

RBF is forbidden

Inserts the incoming transaction.

Conditions of success:

  • no double spend

If conditions are not met, leaves the mempool unchanged and fails with a double spend error.



Allowed

RBF may occur

Identifies double spends in mempool and their owning transactions checking in order every input of the incoming transaction.

Removes all mempool transactions owning double spends and inserts the incoming transaction.

Conditions of success:

  • on absence of double spends, always succeeds
  • on double spends, the incoming transaction has a higher fee/mass ratio than the mempool transaction owning the first double spend

If conditions are not met, leaves the mempool unchanged and fails with a double spend or a tx fee/mass too low error.



Mandatory

RBF must occur

Identifies double spends in mempool and their owning transactions checking in order every input of the incoming transaction.

Removes the mempool transaction owning the double spends and inserts the incoming transaction.

Conditions of success:

  • at least one double spend
  • all double spends belong to the same mempool transaction
  • the incoming transaction has a higher fee/mass ratio than the mempool double spending transaction.

If conditions are not met, leaves the mempool unchanged and fails with a double spend or a tx fee/mass too low error.