pub struct RebalancingWeightedTransactionSelector { /* private fields */ }Implementations
Sourceimpl RebalancingWeightedTransactionSelector
impl RebalancingWeightedTransactionSelector
pub fn new(policy: Policy, transactions: Vec<CandidateTransaction>) -> Self
Sourcepub fn select_transactions(&mut self) -> Vec<Transaction>
pub fn select_transactions(&mut self) -> Vec<Transaction>
select_transactions implements a probabilistic transaction selection algorithm. The algorithm, roughly, is as follows:
- We assign a probability to each transaction equal to: (candidateTx.Value^alpha) / Σ(tx.Value^alpha) Where the sum of the probabilities of all txs is 1.
- We draw a random number in [0,1) and select a transaction accordingly.
- If it’s valid, add it to the selectedTxs and remove it from the candidates.
- Continue iterating the above until we have either selected all available transactions or ran out of gas/block space.
Note that we make two optimizations here:
- Draw a number in [0,Σ(tx.Value^alpha)) to avoid normalization
- Instead of removing a candidate after each iteration, mark it for deletion. Once the sum of probabilities of marked transactions is greater than REBALANCE_THRESHOLD percent of the sum of probabilities of all transactions, rebalance.
select_transactions loops over the candidate transactions and appends the ones that will be included in the next block into selected_txs.